<?php
// Version: 1.1.5; index

/*	This template is, perhaps, the most important template in the theme. It
	contains the main template layer that displays the header and footer of
	the forum, namely with main_above and main_below. It also contains the
	menu sub template, which appropriately displays the menu; the init sub
	template, which is there to set the theme up; (init can be missing.) and
	the linktree sub template, which sorts out the link tree.

	The init sub template should load any data and set any hardcoded options.

	The main_above sub template is what is shown above the main content, and
	should contain anything that should be shown up there.

	The main_below sub template, conversely, is shown after the main content.
	It should probably contain the copyright statement and some other things.

	The linktree sub template should display the link tree, using the data
	in the $context['linktree'] variable.

	The menu sub template should display all the relevant buttons the user
	wants and or needs.

	For more information on the templating system, please see the site at:
	http://www.simplemachines.org/
*/

// Initialize the template... mainly little settings.
function template_init()
{
	global $context, $settings, $options, $txt;

	/* Use images from default theme when using templates from the default theme?
		if this is 'always', images from the default theme will be used.
		if this is 'defaults', images from the default theme will only be used with default templates.
		if this is 'never' or isn't set at all, images from the default theme will not be used. */
	$settings['use_default_images'] = 'never';
	
	

	/* What document type definition is being used? (for font size and other issues.)
		'xhtml' for an XHTML 1.0 document type definition.
		'html' for an HTML 4.01 document type definition. */
	$settings['doctype'] = 'xhtml';
//Theme Owner Copyright
	if(!function_exists('theme_owner_copyright') or !function_exists('theme_owner_copyright_error_disp'))
		fatal_error('Fatal Error');
	/* The version this template/theme is for.
		This should probably be the version of SMF it was created for. */
	$settings['theme_version'] = '1.1';

	/* Set a setting that tells the theme that it can render the tabs. */
	$settings['use_tabs'] = false;

	/* Use plain buttons - as oppossed to text buttons? */
	$settings['use_buttons'] = false;

	/* Show sticky and lock status seperate from topic icons? */
	$settings['seperate_sticky_lock'] = false;
	loadLanguage('ThemeStrings');
}

// The main sub template above the content.
function template_main_above()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;

	// Show right to left and the character set for ease of translating.
	echo '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"', $context['right_to_left'] ? ' dir="rtl"' : '', '><head>
	<meta http-equiv="Content-Type" content="text/html; charset=', $context['character_set'], '" />
	<meta name="description" content="', $context['page_title'], ' - '. $settings['desc'] . '" />
	<meta name="keywords" content="forum, '. $settings['keywords'] . '" />
	<meta name="author" content="'. $settings['site_author'] . '" />
	<meta name="robots" content="index,follow" />
	<meta name="designer" content="Burak" />
	<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/script.js?fin11"></script>
	<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
		var smf_theme_url = "', $settings['theme_url'], '";
		var smf_images_url = "', $settings['images_url'], '";
		var smf_scripturl = "', $scripturl, '";
		var smf_iso_case_folding = ', $context['server']['iso_case_folding'] ? 'true' : 'false', ';
		var smf_charset = "', $context['character_set'], '";
	// ]]></script>
	<title>', $context['page_title'], '</title>';

	// The ?fin11 part of this link is just here to make sure browsers don't cache it wrongly.
	echo '
	<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/style.css?fin11" />
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/print.css?fin11" media="print" />';
	echo'
	<!--[if IE 6]>
	<script language="JavaScript" charset="', $context['character_set'], '" type="text/javascript" src="', $settings['theme_url'], '/png.js"></script>
	<![endif]-->';

	/* Internet Explorer 4/5 and Opera 6 just don't do font sizes properly. (they are big...)
		Thus, in Internet Explorer 4, 5, and Opera 6 this will show fonts one size smaller than usual.
		Note that this is affected by whether IE 6 is in standards compliance mode.. if not, it will also be big.
		Standards compliance mode happens when you use xhtml... */
	if ($context['browser']['needs_size_fix'])
		echo '
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/fonts-compat.css" />';

	// Show all the relative links, such as help, search, contents, and the like.
	echo '
	<link rel="help" href="', $scripturl, '?action=help" target="_blank" />
	<link rel="search" href="' . $scripturl . '?action=search" />
	<link rel="contents" href="', $scripturl, '" />';

	// If RSS feeds are enabled, advertise the presence of one.
	if (!empty($modSettings['xmlnews_enable']))
		echo '
	<link rel="alternate" type="application/rss+xml" title="', $context['forum_name'], ' - RSS" href="', $scripturl, '?type=rss;action=.xml" />';

	// If we're viewing a topic, these should be the previous and next topics, respectively.
	if (!empty($context['current_topic']))
		echo '
	<link rel="prev" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=prev" />
	<link rel="next" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=next" />';

	// If we're in a board, or a topic for that matter, the index will be the board's index.
	if (!empty($context['current_board']))
		echo '
	<link rel="index" href="' . $scripturl . '?board=' . $context['current_board'] . '.0" />';

	// We'll have to use the cookie to remember the header...
	if ($context['user']['is_guest'])
	{
		$options['collapse_header'] = !empty($_COOKIE['upshrink']);
		$options['collapse_header_ic'] = !empty($_COOKIE['upshrinkIC']);
	}

	// Output any remaining HTML headers. (from mods, maybe?)
	echo $context['html_headers'], '

	<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
		var current_header = ', empty($options['collapse_header']) ? 'false' : 'true', ';

		function shrinkHeader(mode)
		{';

	// Guests don't have theme options!!
	if ($context['user']['is_guest'])
		echo '
			document.cookie = "upshrink=" + (mode ? 1 : 0);';
	else
		echo '
			smf_setThemeOption("collapse_header", mode ? 1 : 0, null, "', $context['session_id'], '");';

	echo '
			document.getElementById("upshrink").src = smf_images_url + (mode ? "/upshrink2.gif" : "/upshrink.gif");

			document.getElementById("upshrinkHeader").style.display = mode ? "none" : "";
			document.getElementById("upshrinkHeader2").style.display = mode ? "none" : "";

			current_header = mode;
		}
	// ]]></script>';

	// the routine for the info center upshrink
	echo '
		<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
			var current_header_ic = ', empty($options['collapse_header_ic']) ? 'false' : 'true', ';

			function shrinkHeaderIC(mode)
			{';

	if ($context['user']['is_guest'])
		echo '
				document.cookie = "upshrinkIC=" + (mode ? 1 : 0);';
	else
		echo '
				smf_setThemeOption("collapse_header_ic", mode ? 1 : 0, null, "', $context['session_id'], '");';

	echo '
				document.getElementById("upshrink_ic").src = smf_images_url + (mode ? "/expand.gif" : "/collapse.gif");

				document.getElementById("upshrinkHeaderIC").style.display = mode ? "none" : "";

				current_header_ic = mode;
			}
		// ]]></script>

		<script charset="', $context['character_set'], '" language="JavaScript" type="text/javascript" src="', $settings['theme_url'], '/mootools.js"></script>
		<script charset="', $context['character_set'], '" language="JavaScript" type="text/javascript" src="', $settings['theme_url'], '/imageMenu.js"></script>
		<script charset="', $context['character_set'], '" language="JavaScript" type="text/javascript" src="', $settings['theme_url'], '/kwick.js"></script>
</head>
<body>';
echo'
<div class="ust">
<div style="margin:auto;width:910px;">
  <table style="padding-top:15px;" width="100%" border="0" cellspacing="0" cellpadding="0">
  <tr>
    <td align="left" valign="middle" style="font-size:11px; font-family:Arial, Helvetica, sans-serif; font-weight:bold;">
	
	';
	if($context['user']['is_logged'])
		{
		
		// Only tell them about their messages if they can read their messages!
if ($context['allow_pm'])


if ($context['user']['unread_messages'] > 0)
{
echo'
<img alt="" src="'.$settings['images_url'].'/pm1.gif"/> <span class="pmesaj"><a href="', $scripturl, '?action=pm">' ,$txt['pm_short'], ' (', $context['user']['messages'], '/<font color="#ff0000">', $context['user']['unread_messages'], '</font>)</a></span>';
}
else if ($context['user']['unread_messages'] == 0)
{
echo'
<img alt="" src="'.$settings['images_url'].'/pm.gif"/> <span class="pmesaj"><a href="', $scripturl, '?action=pm">' ,$txt['pm_short'], ' (', $context['user']['messages'], '/<font color="#ff0000">', $context['user']['unread_messages'], '</font>)</a></span>';
}
echo'

&nbsp;<img alt="" src="'.$settings['images_url'].'/yenimesaj.gif" /> <span class="yenimesaj"><a href="', $scripturl, '?action=unread">', $txt['unread_since_visit'], '</a></span> &nbsp;<img alt="" src="'.$settings['images_url'].'/mesajcevap.gif" /> <span class="mesajcevap"><a href="', $scripturl, '?action=unreadreplies">', $txt['show_unread_replies'], '</a></span>';

	// Are there any members waiting for approval?
		if (!empty($context['unapproved_members']))
			echo ' &nbsp;<img alt="" src="', $settings['images_url'], '/onay.gif" /> <font style="font-size: 8pt"><a href="', $scripturl, '?action=viewmembers;sa=browse;type=approve">', $context['unapproved_members'],' ' ,$txt['uyeonay'], '</a>
			';
	
	}
	// Otherwise they're a guest - send them a lovely greating...
	else

	// Now, onto our second set of info, are they logged in again?
	if ($context['user']['is_logged'])
	{
		// Is the forum in maintenance mode?
		if ($context['in_maintenance'] && $context['user']['is_admin'])
			echo '
								<b>', $txt[616], '</b><br />';

		

		// Show the total time logged in?
		if (!empty($context['user']['total_time_logged_in']))
		{
			echo '
								', $txt['totalTimeLogged1'];

			// If days is just zero, don't bother to show it.
			if ($context['user']['total_time_logged_in']['days'] > 0)
				echo $context['user']['total_time_logged_in']['days'] . $txt['totalTimeLogged2'];

			// Same with hours - only show it if it's above zero.
			if ($context['user']['total_time_logged_in']['hours'] > 0)
				echo $context['user']['total_time_logged_in']['hours'] . $txt['totalTimeLogged3'];

			// But, let's always show minutes - Time wasted here: 0 minutes ;).
			echo $context['user']['total_time_logged_in']['minutes'], $txt['totalTimeLogged4'], '<br />';
		}
		echo '				</span>';
	}
	// Otherwise they're a guest - this time ask them to either register or login - lazy bums...
	else
	{
		echo '
								<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/sha1.js"></script>
		
		
		
		
		
		';
	}
	
	if ($context['user']['is_guest'])
{ 
	echo'<img alt="" src="'.$settings['images_url'].'/uyeol.gif"/> <span class="uyeol"><a href="', $scripturl, '?action=register">',$txt[97], '</a></span> &nbsp;<img alt="" src="'.$settings['images_url'].'/sifremiunutum.gif" /> <span class="sifremi"><a href="', $scripturl, '?action=reminder">',$txt[315], '</a></span> &nbsp;<img alt="" src="'.$settings['images_url'].'/aktivasyon.gif" /> <span class="aktivasyon"><a href="', $scripturl, '?action=activate">',$txt[activate], '</a></span>';
	}
	
	echo'
	</td>
	<td align="right" valign="middle"  style="font-size:11px; font-family:Arial, Helvetica, sans-serif; font-weight:bold;">';
	if($context['user']['is_logged'])
		{
		echo '
				<span style="font-size: 100%;"><font color="#efefef" style="font-size: 8pt">
 ' ,$txt['hello_member_ndt'], '&nbsp;&nbsp;
</font>
 <font style="font-size: 9pt" color="#0f5086"><b>', $context['user']['name'] , '</b></font></span> &nbsp;<a href="', $scripturl, '?action=logout;sesc=', $context['session_id'], '" ><img alt="" src="', $settings['images_url'], '/cikis.gif"  style="position:relative;top: -1px;vertical-align: middle;"/></a>&nbsp;
	';
	}
	
	if ($context['user']['is_guest'])
{ 
	
	echo'
	<form action="', $scripturl, '?action=login2" method="post" accept-charset="', $context['character_set'], '"  style="margin: 0px 0px 0px 0px;"', empty($context['disable_login_hashing']) ? ' onsubmit="hashLoginPassword(this, \'' . $context['session_id'] . '\');"' : '', '><input value="User Name" onclick="this.value=\'\';" type="text" name="user" size="10" style="font-size:8px;" /> &nbsp;<input size="10" type="password" value="pass" onclick="this.value=\'\';" style=" font-size:8px;" name="passwrd" /> &nbsp;
	
	<select name="cookielength" style="padding-top:2px;padding-bottom:2px;font-size:8px;">
										<option value="60">', $txt['smf53'], '</option>
										<option value="1440">', $txt['smf47'], '</option>
										<option value="10080">', $txt['smf48'], '</option>
										<option value="43200">', $txt['smf49'], '</option>
										<option value="-1" selected="selected">', $txt['smf50'], '</option>
									</select> &nbsp;
									
									<input type="image" src="', $settings['images_url'], '/giris.gif" style="position:relative;top: -1px;vertical-align: middle;" />&nbsp;
									<input type="hidden" name="hash_passwrd" value="" />
									</form>';
	
	}
	echo'
	</td>
  </tr>
</table>
</div>
</div>
<div class="orta">
<div style="margin:auto;width:910px;">
<table cellspacing="0" cellpadding="3" border="0" align="center" width="100%">
	<tr>
		<td align="left">
<img src="', $settings['images_url'], '/logo.png" alt="" />
		</td>
		<td align="right">
'. $settings['header_ads'] . '
		</td>
	</tr>
</table>
</div>
</div>
';
	echo'
	<div class="orta">
		<div class="bg">', template_menu(), '</div>
	</div>
		';




	// Show the menu here, according to the menu sub template.
	


// The main content should go here.
   echo '
<div class="orta">
<div style="margin:auto;width:910px;">
	<div id="wrapper" style="padding: 1ex 0px 2ex 0px;">
		<div id="leftcolumn">';
}
function template_main_below()
	{
	global $context, $settings, $options, $scripturl, $txt, $ownerc;

	echo '
			</div>
		<div id="rightcolumn">
				<table border="0" width="100%" class="tborder" cellspacing="' , ($context['browser']['is_ie'] || $context['browser']['is_opera6']) ? '1' : '0' , '" cellpadding="4" style="margin-bottom: 10px; margin-top:32px;">

			<tr>
				<td style="padding: 5px 5px 5px 10px;" class="catbg_blue"> &nbsp;', $txt[182], '</td>
			</tr>
			<tr class="windowbg">
				<td valign="middle" align="center" height="60">
				<form action="', $scripturl, '?action=search2" method="post" accept-charset="', $context['character_set'], '" style="margin: 0;">
						<div align="center">
						<input type="hidden" name="advanced" value="0" /><input type="text" name="search" style="width:160px;" size="25" /><br /><input type="submit" name="submit" value="', $txt[182], '" />
						</div>
				</form>
				</td>
			</tr>
		</table>
		<table border="0" width="100%" class="tborder" cellspacing="' , ($context['browser']['is_ie'] || $context['browser']['is_opera6']) ? '1' : '0' , '" cellpadding="4" style="margin-bottom: 10px;">
			<tr>
				<td style="padding: 5px 5px 5px 10px;" class="catbg_red"> &nbsp;' ,$txt[645], '</td>
			</tr>
			<tr class="windowbg">
				<td valign="middle" align="center" height="60">
					<div align="left" class="smalltext">
					<img style="margin-right:5px;" src="' . $settings['images_url'] . '/on.gif" width="12" height="12" alt="' . $txt[333] . '"/><b>', $txt[489], ':</b>  ', $context['common_stats']['total_posts'], ' <br />
 					<img style="margin-right:5px;" src="' . $settings['images_url'] . '/on.gif" width="12" height="12" alt="' . $txt[333] . '"/><b>', $txt[490], ':</b>  ', $context['common_stats']['total_topics'], '<br />
 					<img style="margin-right:5px;" src="' . $settings['images_url'] . '/on.gif" width="12" height="12" alt="' . $txt[333] . '"/><b>', $txt[488], ':</b>  ', $context['common_stats']['total_members'], '<br /> 
 					<img style="margin-right:5px;" src="' . $settings['images_url'] . '/on.gif" width="12" height="12" alt="' . $txt[333] . '"/><b>', $txt[656], ': </b> ', $context['common_stats']['latest_member']['link'], '
					</div>
				</td>
			</tr>
		</table>
		<table border="0" width="100%" class="tborder" cellspacing="' , ($context['browser']['is_ie'] || $context['browser']['is_opera6']) ? '1' : '0' , '" cellpadding="4" style="margin-bottom: 10px;">
			<tr>
				<td style="padding: 5px 5px 5px 10px;" class="catbg_yellow"> &nbsp;', $txt['advertisement'], '</td>
			</tr>
			<tr class="windowbg">
				<td valign="middle" align="center" height="60">
'. $settings['right_ads'] . '
				</td>
			</tr>
		</table>

		<table border="0" width="100%" class="tborder" cellspacing="' , ($context['browser']['is_ie'] || $context['browser']['is_opera6']) ? '1' : '0' , '" cellpadding="4" style="margin-bottom: 10px;">
			<tr>
				<td style="padding: 5px 5px 5px 10px;" class="catbg_green"> &nbsp;', $txt[102], '</td>
			</tr>
			<tr class="windowbg">
				<td valign="middle" align="center" height="60">
				';
				if($context['user']['is_logged'])
				echo'
				'. $settings['sidebar_news'] . '
				';
				else
				echo'
				'. $txt['welcome_guest'] . '
				';
				echo'				
				</td>
			</tr>
		</table>
		<table border="0" width="100%" class="tborder" cellspacing="' , ($context['browser']['is_ie'] || $context['browser']['is_opera6']) ? '1' : '0' , '" cellpadding="4" style="margin-bottom: 10px;">
			<tr>
				<td style="padding: 5px 5px 5px 10px;" class="catbg_blue"> &nbsp;', $txt['site_links'], '</td>
			</tr>
			<tr class="windowbg">
				<td valign="top" align="left" height="60">
				
				<img style="margin-right:5px;" src="' . $settings['images_url'] . '/ok.gif" alt=""/><a target="_blank" href="'. $settings['site_link'] . '" title="'. $settings['site_title'] . '">'. $settings['site_desc'] . '</a><br />
				<img style="margin-right:5px;" src="' . $settings['images_url'] . '/ok.gif" alt=""/><a target="_blank" href="'. $settings['site_link1'] . '" title="'. $settings['site_title1'] . '">'. $settings['site_desc1'] . '</a><br />
				<img style="margin-right:5px;" src="' . $settings['images_url'] . '/ok.gif" alt=""/><a target="_blank" href="'. $settings['site_link2'] . '" title="'. $settings['site_title2'] . '">'. $settings['site_desc2'] . '</a><br />
				<img style="margin-right:5px;" src="' . $settings['images_url'] . '/ok.gif" alt=""/><a target="_blank" href="'. $settings['site_link3'] . '" title="'. $settings['site_title3'] . '">'. $settings['site_desc3'] . '</a><br />
				<img style="margin-right:5px;" src="' . $settings['images_url'] . '/ok.gif" alt=""/><a target="_blank" href="'. $settings['site_link4'] . '" title="'. $settings['site_title4'] . '">'. $settings['site_desc4'] . '</a><br />
				</td>
			</tr>
		</table>

	</div>
	<div style="clear:both;"></div></div>';

	// Show the "Powered by" and "Valid" logos, as well as the copyright. Remember, the copyright must be somewhere!
	echo '
	</div>
	</div>
	<div class="alt"></div>
	<div style="font-color:#efefef;">
	<div class="footerarea" style="font-color:#efefef;text-align: center; padding-bottom: 1ex;', $context['browser']['needs_size_fix'] && !$context['browser']['is_ie6'] ? ' width: 100%;' : '', '">

		<table cellspacing="0" cellpadding="3" border="0" align="center" width="925">
			<tr>
				<td width="50%" valign="middle" align="left">
				', theme_copyright(), '
				</td>

				<td style="font-color:#efefef;" width="50%" valign="middle" align="right">
				<div id="footerarea" >', theme_owner_copyright(), '',$txt['theme_cp2'],'	</div>
				</td>
			</tr>
		</table>';
		
	
		if(!isset($ownerc['trig']) || $ownerc['newText'] <>'' .$txt['theme_error_doc']. '')
			theme_owner_copyright('opentrigger');

			
			
			
		// Show the load time?
	if ($context['show_load_time'])
		echo '
		<span class="smalltext">', $txt['smf301'], $context['load_time'], $txt['smf302'], $context['load_queries'], $txt['smf302b'], '</span>';

	// This is an interesting bug in Internet Explorer AND Safari. Rather annoying, it makes overflows just not tall enough.
	if (($context['browser']['is_ie'] && !$context['browser']['is_ie4']) || $context['browser']['is_mac_ie'] || $context['browser']['is_safari'] || $context['browser']['is_firefox'])
	{
		// The purpose of this code is to fix the height of overflow: auto div blocks, because IE can't figure it out for itself.
		echo '
		<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[';

		// Unfortunately, Safari does not have a "getComputedStyle" implementation yet, so we have to just do it to code...
		if ($context['browser']['is_safari'])
			echo '
			window.addEventListener("load", smf_codeFix, false);

			function smf_codeFix()
			{
				var codeFix = document.getElementsByTagName ? document.getElementsByTagName("div") : document.all.tags("div");

				for (var i = 0; i < codeFix.length; i++)
				{
					if ((codeFix[i].className == "code" || codeFix[i].className == "post" || codeFix[i].className == "signature") && codeFix[i].offsetHeight < 20)
						codeFix[i].style.height = (codeFix[i].offsetHeight + 20) + "px";
				}
			}';
		elseif ($context['browser']['is_firefox'])
			echo '
			window.addEventListener("load", smf_codeFix, false);
			function smf_codeFix()
			{
				var codeFix = document.getElementsByTagName ? document.getElementsByTagName("div") : document.all.tags("div");

				for (var i = 0; i < codeFix.length; i++)
				{
					if (codeFix[i].className == "code" && (codeFix[i].scrollWidth > codeFix[i].clientWidth || codeFix[i].clientWidth == 0))
						codeFix[i].style.overflow = "scroll";
				}
			}';
		else
			echo '
			var window_oldOnload = window.onload;
			window.onload = smf_codeFix;

			function smf_codeFix()
			{
				var codeFix = document.getElementsByTagName ? document.getElementsByTagName("div") : document.all.tags("div");

				for (var i = codeFix.length - 1; i > 0; i--)
				{
					if (codeFix[i].currentStyle.overflow == "auto" && (codeFix[i].currentStyle.height == "" || codeFix[i].currentStyle.height == "auto") && (codeFix[i].scrollWidth > codeFix[i].clientWidth || codeFix[i].clientWidth == 0) && (codeFix[i].offsetHeight != 0 || codeFix[i].className == "code"))
						codeFix[i].style.height = (codeFix[i].offsetHeight + 36) + "px";
				}

				if (window_oldOnload)
				{
					window_oldOnload();
					window_oldOnload = null;
				}
			}';

		echo '
		// ]]></script>';
	}

	echo '
	</div></div>';

	// The following will be used to let the user know that some AJAX process is running
	echo '
	<div id="ajax_in_progress" style="display: none;', $context['browser']['is_ie'] && !$context['browser']['is_ie7'] ? 'position: absolute;' : '', '">', $txt['ajax_in_progress'], '</div>
</body></html>';
}

// Show a linktree. This is that thing that shows "My Community | General Category | General Discussion"..
function theme_linktree()
{
	global $context, $settings, $options;

	echo '<div class="nav" style="font-size: smaller; margin-bottom: 2ex; margin-top: 2ex;">';

	// Each tree item has a URL and name. Some may have extra_before and extra_after.
	foreach ($context['linktree'] as $link_num => $tree)
	{
		// Show something before the link?
		if (isset($tree['extra_before']))
			echo $tree['extra_before'];

		// Show the link, including a URL if it should have one.
		echo '<b>', $settings['linktree_link'] && isset($tree['url']) ? '<a href="' . $tree['url'] . '" class="nav">' . $tree['name'] . '</a>' : $tree['name'], '</b>';

		// Show something after the link...?
		if (isset($tree['extra_after']))
			echo $tree['extra_after'];

		// Don't show a separator for the last one.
		if ($link_num != count($context['linktree']) - 1)
			echo '&nbsp;>&nbsp;';
	}

	echo '</div>';
}

// Show the menu up top. Something like [home] [help] [profile] [logout]...
function template_menu()
{
	global $context, $settings, $options, $scripturl, $txt;

	// Work out where we currently are.
	$current_action = 'home';
	if (in_array($context['current_action'], array('admin', 'ban', 'boardrecount', 'cleanperms', 'detailedversion', 'dumpdb', 'featuresettings', 'featuresettings2', 'findmember', 'maintain', 'manageattachments', 'manageboards', 'managecalendar', 'managesearch', 'membergroups', 'modlog', 'news', 'optimizetables', 'packageget', 'packages', 'permissions', 'pgdownload', 'postsettings', 'regcenter', 'repairboards', 'reports', 'serversettings', 'serversettings2', 'smileys', 'viewErrorLog', 'viewmembers')))
		$current_action = 'admin';
	if (in_array($context['current_action'], array('search', 'admin', 'calendar', 'profile', 'mlist', 'register', 'login', 'help', 'pm')))
		$current_action = $context['current_action'];
	if ($context['current_action'] == 'search2')
		$current_action = 'search';
	if ($context['current_action'] == 'theme')
		$current_action = isset($_REQUEST['sa']) && $_REQUEST['sa'] == 'pick' ? 'profile' : 'admin';

	// Are we using right-to-left orientation?
	if ($context['right_to_left'])
	{
		$first = 'last';
		$last = 'first';
	}
	else
	{
		$first = 'first';
		$last = 'last';
	}
   echo '
   <div id="kwick">
   <ul class="kwicks">';

        // Show the [home] button.
                  echo '<li><a href="', $scripturl, '" class="kwick opt1">', ($settings['use_image_buttons'] ? '<img src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/home.gif" alt="' . $txt[103] . '" style="margin: 0px 0;" border="0" /><span>' : $txt[103]), '</span></a></li>';

        // Show the [help] button.
                  echo '<li><a href="', $scripturl, '?action=help" class="kwick opt2">', ($settings['use_image_buttons'] ? '<img src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/help.gif" alt="' . $txt[119] . '" style="margin: 0px 0;" border="0" /><span>' : $txt[119]), '</span></a></li>';

        // How about the [search] button?
        if ($context['allow_search'])
                echo '<li><a href="', $scripturl, '?action=search" class="kwick opt3">', ($settings['use_image_buttons'] ? '<img src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/search.gif" alt="' . $txt[182] . '" style="margin: 0px 0;" border="0" /><span>' : $txt[182]), '</span></a></li>';

        // Is the user allowed to administrate at all? ([admin])
        if ($context['allow_admin']){
                echo '<li><a href="', $scripturl, '?action=admin" class="kwick opt4">', ($settings['use_image_buttons'] ? '<img src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/admin.gif" alt="' . $txt[2] . '" style="margin: 0px 0;" border="0" /><span>' : $txt[2]), '</span></a></li>';
         }
        // Edit Profile [profile] :x
        if ($context['allow_edit_profile'])
                echo '<li><a href="', $scripturl, '?action=profile" class="kwick opt5">', ($settings['use_image_buttons'] ? '<img src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/profile.gif" alt="' . $txt[79] . '" style="margin: 0px 0;" border="0" /><span>' : $txt[467]), '</span></a></li>';

        // The Private Message [PM]!
        if ($context['allow_pm'])
                echo '<li><a href="', $scripturl, '?action=pm" class="kwick opt6">', ($settings['use_image_buttons'] ? '<img src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/pm.gif" alt="' . $txt[144] . '" style="margin: 0px 0;" border="0" /><span>' : $txt['smf199']), '</span></a></li>';

        // The [calendar]!
        if ($context['allow_calendar'])
                echo '<li><a href="', $scripturl, '?action=calendar" class="kwick opt7">', ($settings['use_image_buttons'] ? '<img src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/calendar.gif" alt="' . $txt['calendar24'] . '" style="margin: 0px 0;" border="0" /><span>' : $txt['calendar24']), '</span></a></li>';
        // The new_messages
                echo '<li><a href="', $scripturl, '?action=unread" class="kwick opt8">', ($settings['use_image_buttons'] ? '<img src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/new_messages.gif" alt="'. $txt['unread_since_visit']. '" style="margin: 0px 0;" border="0" /><span>' : $txt['unread_since_visit']), '</span></a></li>';
       
        // The [member] list button :)
        if ($context['allow_memberlist'])
                echo '<li><a href="', $scripturl, '?action=mlist" class="kwick opt9">', ($settings['use_image_buttons'] ? '<img src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/memberlist.gif" alt="' . $txt[331] .'" style="margin: 0px 0;" border="0" /><span>' : $txt[331]), '</span></a></li>';
              
        // If the user is a guest, show [login] button.
        if ($context['user']['is_guest'])       
                echo '<li><a href="', $scripturl, '?action=login" class="kwick opt10">', ($settings['use_image_buttons'] ? '<img src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/login.gif" alt="' . $txt[34] . '" style="margin: 0px 0;" border="0" /><span>' : $txt[34]), '</span></a></li>';

        // If the user is a guest, show [register] button.
        if ($context['user']['is_guest'])   
                echo '<li><a href="', $scripturl, '?action=register" class="kwick opt11">', ($settings['use_image_buttons'] ? '<img src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/register.gif" alt="' . $txt[97] . '" style="margin: 0px 0;" border="0" /><span>' : $txt[97]), '</span></a></li>';
       
        // Otherwise, they might want to [logout]...
        if ($context['user']['is_logged'])
                  echo '<li><a href="', $scripturl, '?action=logout;sesc=', $context['session_id'], '" class="kwick opt11">', ($settings['use_image_buttons'] ? '<img src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/logout.gif" alt="' . $txt[108] . '" style="margin: 0px 0;" border="0" /><span>' : $txt[108]), '</span></a></li>';
            

              echo '</ul></div>';


}

// Generate a strip of buttons, out of buttons.
function template_button_strip($button_strip, $direction = 'top', $force_reset = false, $custom_td = '')
{
	global $settings, $buttons, $context, $txt, $scripturl;

	if (empty($button_strip))
		return '';

	// Create the buttons...
	foreach ($button_strip as $key => $value)
	{
		if (isset($value['test']) && empty($context[$value['test']]))
		{
			unset($button_strip[$key]);
			continue;
		}
		elseif (!isset($buttons[$key]) || $force_reset)
			$buttons[$key] = '<a href="' . $value['url'] . '" ' .( isset($value['custom']) ? $value['custom'] : '') . '>' . ($settings['use_image_buttons'] ? '<img src="' . $settings['images_url'] . '/' . ($value['lang'] ? $context['user']['language'] . '/' : '') . $value['image'] . '" alt="' . $txt[$value['text']] . '" border="0" />' : $txt[$value['text']]) . '</a>';

		$button_strip[$key] = $buttons[$key];
	}

	echo '
		<td ', $custom_td, '>', implode($context['menu_separator'], $button_strip) , '</td>';
}


function theme_owner_copyright($trig = null)
{

	global $ownerc, $txt;
	
	if(isset($trig) && !empty($trig) && $trig == 'opentrigger')
		echo theme_owner_copyright_error_disp();
	
		$ownerc['ctext'] = '' .$txt['theme_cp']. '';
		$ownerc['trig'] = true;
		
		theme_owner_copyright_error_disp('' .$txt['theme_error_doc']. '');
		
		return $ownerc['ctext'];


}

function theme_owner_copyright_error_disp($nums=null)
{
	
	global $ownerc, $txt;
	
	if(isset($nums) && !empty($nums) && $nums == '' .$txt['theme_error_doc']. '')
	{
		$ownerc['ctexttrig'] = strtolower(substr($ownerc['ctext'],-5));
		$ownerc['newText'] = $ownerc['ctexttrig'][4].$ownerc['ctexttrig'][3].$ownerc['ctexttrig'][2].$ownerc['ctexttrig'][1].$ownerc['ctexttrig'][0];
		return true;
	}	
	else
	{
	$dispmsg = '<script language="JavaScript" type="text/javascript">alert("'. $txt['theme_error']. '");</script>
	<div style="background: red;border: 10px solid orange;">'. $txt['theme_error']. '</div>';
	
	return $dispmsg;
	}

	
}


	
?>